<?php
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
/**
 * The admin-specific Ajax files.
 *
 * @link       http://rextheme.com/
 * @since      1.0.0
 *
 * @package    Wpvr
 * @subpackage Wpvr/admin
 */

class Wpvr_Ajax {

  /**
   * Preview show ajax function
   */
  function wpvr_show_preview() {
      $panoid ='';
      $postid = sanitize_text_field($_POST['postid']);
      $post_type = get_post_type( $postid );

      $panoid = 'pano'.$postid;

      $control = sanitize_text_field($_POST['control']);
      if ($control == 'on') {
        $control = true;
      }
      else {
        $control = false;
      }

      $autoload = sanitize_text_field($_POST['autoload']);
      if ($autoload == 'on') {
        $autoload = true;
      }
      else {
        $autoload = false;
      }

      $default_scene = '';
      $default_scene = sanitize_text_field($_POST['defaultscene']);

      $preview = '';
      $preview = esc_url($_POST['preview']);

      $autorotation = '';
      $autorotation = sanitize_text_field($_POST['autorotation']);
      $autorotationinactivedelay = '';
      $autorotationinactivedelay = sanitize_text_field($_POST['autorotationinactivedelay']);
      $autorotationstopdelay = '';
      $autorotationstopdelay = sanitize_text_field($_POST['autorotationstopdelay']);

      $scene_fade_duration = '';
      $scene_fade_duration = sanitize_text_field($_POST['scenefadeduration']);

      $panodata = $_POST['panodata'];

      //===Error Control and Validation===//

      if ($panodata["scene-list"] != "") {
        foreach ($panodata["scene-list"] as $scenes_val) {

          $scene_id_validate = $scenes_val["scene-id"];
          if (!empty($scene_id_validate)) {
            $scene_id_validated = preg_replace('/[^0-9a-zA-Z_]/',"",$scene_id_validate);
            if ($scene_id_validated != $scene_id_validate) {
              wp_send_json_error('<p><span>Warning:</span> The scene id can only contain letters and numbers</p>');
              die();
            }
            if (empty($scenes_val["scene-attachment-url"])) {
              wp_send_json_error('<p><span>Warning:</span> A scene image is required for every scene.</p>');
              die();
            }

            if ($scenes_val["hotspot-list"] != "") {
              foreach ($scenes_val["hotspot-list"] as $hotspot_val) {
                $hotspot_title_validate = $hotspot_val["hotspot-title"];

                if (!empty($hotspot_title_validate)) {
                  $hotspot_title_validated = preg_replace('/[^0-9a-zA-Z_]/',"",$hotspot_title_validate);
                  if ($hotspot_title_validated != $hotspot_title_validate) {
                    wp_send_json_error('<p><span>Warning:</span> Hotspot title can only contain letters and numbers</p>');
                    die();
                  }

                  $hotspot_pitch_validate = $hotspot_val["hotspot-pitch"];
                  if (!empty($hotspot_pitch_validate)) {
                    $hotspot_pitch_validated = preg_replace('/[^0-9.-]/','',$hotspot_pitch_validate);
                    if ($hotspot_pitch_validated != $hotspot_pitch_validate) {
                      wp_send_json_error('<p><span>Warning:</span> Hotspot pitch can only contain float numbers</p>');
                      die();
                    }
                  }

                  $hotspot_yaw_validate = $hotspot_val["hotspot-yaw"];
                  if (!empty($hotspot_yaw_validate)) {
                    $hotspot_yaw_validated = preg_replace('/[^0-9.-]/','',$hotspot_yaw_validate);
                    if ($hotspot_yaw_validated != $hotspot_yaw_validate) {
                      wp_send_json_error('<p><span>Warning:</span> Hotspot yaw can only contain float numbers</p>');
                      die();
                    }
                  }
                  $hotspot_type_validate = $hotspot_val["hotspot-type"];
                  $hotspot_url_validate = $hotspot_val["hotspot-url"];
                  if (!empty($hotspot_url_validate)) {
                    $hotspot_url_validated = esc_url($hotspot_url_validate);
                    if ($hotspot_url_validated != $hotspot_url_validate) {
                      wp_send_json_error('<p><span>Warning:</span> Hotspot Url is invalid</p>');
                      die();
                    }
                  }
                  $hotspot_content_validate = $hotspot_val["hotspot-content"];

                  $hotspot_scene_validate = $hotspot_val["hotspot-scene"];

                  if ($hotspot_type_validate == "info") {
                    if (!empty($hotspot_scene_validate)) {
                      wp_send_json_error('<p><span>Warning:</span> Don\'t add Target Scene ID on info type hotspot</p>');
                      die();
                    }
                    if (!empty($hotspot_url_validate) && !empty($hotspot_content_validate)) {
                      wp_send_json_error('<p><span>Warning:</span> Don\'t add Url and On click content both on same hotspot.</p>');
                      die();
                    }
                  }

                  if ($hotspot_type_validate == "scene") {
                    if (empty($hotspot_scene_validate)) {
                      wp_send_json_error('<p><span>Warning:</span> Target scene id is required for scene type hotspot.</p>');
                      die();
                    }
                    if (!empty($hotspot_url_validate) || !empty($hotspot_content_validate)) {
                      wp_send_json_error('<p><span>Warning:</span> Don\'t add Url or On click content on scene type hotspot.</p>');
                      die();
                    }
                  }
                }
              }
            }
          }
        }
      }
      //===Error Control and Validation===//

      foreach ($panodata["scene-list"] as $panoscenes) {
        if ($panoscenes['dscene'] == 'on') {
          $default_scene = $panoscenes['scene-id'];
        }
      }
      if (empty($default_scene)) {
        wp_send_json_error('<p><span>Warning:</span> Default scene is required. Set a scene as deafualt to load it by deafult.</p>');
        die();
      }

      $default_data = array();
      $default_data = array(__( "firstScene" )=>$default_scene,__( "sceneFadeDuration" )=>$scene_fade_duration);
      $scene_data = array();
      // var_dump($panodata["scene-list"]);
      // die();
      foreach ($panodata["scene-list"] as $panoscenes) {

        if (!empty($panoscenes['scene-id'])) {
          $hotspot_datas = $panoscenes["hotspot-list"];
          $hotspots = array();
          foreach ($hotspot_datas as $hotspot_data) {

            if (!empty($hotspot_data["hotspot-title"])) {
              $hotspot_info = array(
                __( "text" )=>$hotspot_data["hotspot-title"],
                __( "pitch" )=>$hotspot_data["hotspot-pitch"],
                __( "yaw" )=>$hotspot_data["hotspot-yaw"],
                __( "type" )=>$hotspot_data["hotspot-type"],
                __( "URL" )=>$hotspot_data["hotspot-url"],
                __( "clickHandlerArgs" )=>$hotspot_data["hotspot-content"],
                __( "createTooltipArgs" )=>$hotspot_data["hotspot-hover"],
                __( "sceneId" )=>$hotspot_data["hotspot-scene"]);
              array_push($hotspots, $hotspot_info); 
              }
          }

          $scene_info = array();
          $scene_info = array(__( "type" )=>$panoscenes["scene-type"],__( "panorama" )=>$panoscenes["scene-attachment-url"],__( "hotSpots" )=>$hotspots);
          $scene_array = array();
          $scene_array = array(
            __($panoscenes["scene-id"])=>$scene_info
          );
          $scene_data[$panoscenes["scene-id"]] = $scene_info; 
          }
      }

      $pano_id_array = array();
      $pano_id_array = array(__( "panoid" )=>$panoid);
      $pano_response = array();
      $pano_response = array(__( "autoLoad" )=>$autoload,__( "showControls" )=>$control,__( "preview" )=>$preview,__( "autoRotate" )=>$autorotation,__( "autoRotateInactivityDelay" )=>$autorotationinactivedelay,__( "autoRotateStopDelay" )=>$autorotationstopdelay,__( "default" )=>$default_data,__( "scenes" )=>$scene_data);

      if (empty($autorotation)) {
          unset($pano_response['autoRotate']);
          unset($pano_response['autoRotateInactivityDelay']);
          unset($pano_response['autoRotateStopDelay']);
      }
      if (empty($autorotationinactivedelay)) {
          unset($pano_response['autoRotateInactivityDelay']);
      }
      if (empty($autorotationstopdelay)) {
          unset($pano_response['autoRotateStopDelay']);
      }
      $response = array();
      $response = array($pano_id_array,$pano_response);

      wp_send_json_success( $response );
  }

  /**
  * Video Preview show ajax function
  */
  function wpvrvideo_preview() {
      $panoid ='';
      $postid = sanitize_text_field($_POST['postid']);
      $panoid = 'pano'.$postid;
      $randid = rand(1000, 1000000);
      $vidid = 'vid'.$randid;
      $videourl = sanitize_url($_POST['videourl']);

      $vidtype = '';
      if (strpos($videourl, 'youtube') > 0) {
        $vidtype = 'youtube';
        $explodeid = '';
        $explodeid = explode("=",$videourl);
        $foundid = '';
        $foundid = $explodeid[1];
        $html = '';
        $html .= '<iframe width="600" height="400" src="https://www.youtube.com/embed/'.$foundid.'" frameborder="0" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>';
        
      } elseif (strpos($videourl, 'youtu.be') > 0) {
        $vidtype = 'youtube';
        $explodeid = '';
        $explodeid = explode("/",$videourl);
        $foundid = '';
        $foundid = $explodeid[3];
        $html = '';
        $html .= '<iframe width="600" height="400" src="https://www.youtube.com/embed/'.$foundid.'" frameborder="0" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>';
        
      }
      elseif (strpos($videourl, 'vimeo') > 0) {
        $vidtype = 'vimeo';
        $explodeid = '';
        $explodeid = explode("/",$videourl);
        $foundid = '';
        $foundid = $explodeid[3];
        $html = '';
        $html .= '<iframe src="https://player.vimeo.com/video/'.$foundid.'" width="600" height="400" frameborder="0" webkitallowfullscreen mozallowfullscreen allowfullscreen></iframe>';
        
      } else {
        $vidtype = 'selfhost';
        $vidautoplay = '';
        $vidautoplay = sanitize_text_field($_POST['vidautoplay']);
        if ($vidautoplay == 'on') {
            $vidautoplay = 'autoplay';
        }
        else {
          $vidautoplay = '';
        }

        $vidcontrol = '';
        $vidcontrol = sanitize_text_field($_POST['vidcontrol']);
        if ($vidcontrol == 'on') {
          $vidcontrol = 'controls';
        }
        else {
          $vidcontrol = '';
        }

        $html = '';
        $html .= '<video id="'.$vidid.'" class="video-js vjs-default-skin vjs-big-play-centered" controls preload="none" style="width:100%;height:400px;" poster="" >';
          $html .= '<source src="'.$videourl.'" type="video/mp4"/>';
          $html .= '<p class="vjs-no-js">';
            $html .= 'To view this video please enable JavaScript, and consider upgrading to a web browser that <a href="http://videojs.com html5-video-support/" target="_blank">supports HTML5 video</a>';
            $html .= '</p>';
        $html .= '</video>';  
      }

      $response = array();
      $response = array(__( "panoid" )=>$panoid,__( "panodata" )=>$html,__( "vidid" )=>$vidid,__( "vidtype" )=>$vidtype);
      wp_send_json_success( $response );
  }

  function wpvr_save_data() {
      $panoid ='';
      $postid = sanitize_text_field($_POST['postid']);
      $post_type = get_post_type( $postid );
      if ($post_type != 'wpvr_item') {
        die();
      }
      $panoid = 'pano'.$postid;

      $pnovideo = $_POST['panovideo'];
      if ($pnovideo == "on") {


        $vidid = 'vid'.$postid;
        $videourl = sanitize_url($_POST['videourl']);
        $vidtype = '';
        if (strpos($videourl, 'youtube') > 0) {
          $vidtype = 'youtube';
          $explodeid = '';
          $explodeid = explode("=",$videourl);
          $foundid = '';
          $foundid = $explodeid[1];
          $html = '';
          $html .= '<iframe width="600" height="400" src="https://www.youtube.com/embed/'.$foundid.'" frameborder="0" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>';
          
        } elseif (strpos($videourl, 'youtu.be') > 0) {
          $vidtype = 'youtube';
          $explodeid = '';
          $explodeid = explode("/",$videourl);
          $foundid = '';
          $foundid = $explodeid[3];
          $html = '';
          $html .= '<iframe width="600" height="400" src="https://www.youtube.com/embed/'.$foundid.'" frameborder="0" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>';
          
        }

        elseif (strpos($videourl, 'vimeo') > 0) {
          $vidtype = 'vimeo';
          $explodeid = '';
          $explodeid = explode("/",$videourl);
          $foundid = '';
          $foundid = $explodeid[3];
          $html = '';
          $html .= '<iframe src="https://player.vimeo.com/video/'.$foundid.'" width="600" height="400" frameborder="0" webkitallowfullscreen mozallowfullscreen allowfullscreen></iframe>';
          
        } else {
          $vidtype = 'selfhost';
          $vidautoplay = '';
          $vidautoplay = sanitize_text_field($_POST['vidautoplay']);
          if ($vidautoplay == 'on') {
              $vidautoplay = 'autoplay';
          }
          else {
            $vidautoplay = '';
          }

          $vidcontrol = '';
          $vidcontrol = sanitize_text_field($_POST['vidcontrol']);
          if ($vidcontrol == 'on') {
            $vidcontrol = 'controls';
          }
          else {
            $vidcontrol = '';
          }

          $html = '';
          $html .= '<video id="'.$vidid.'" class="video-js vjs-default-skin vjs-big-play-centered" controls preload="none" style="width:100%;height:100%;" poster="" >';
            $html .= '<source src="'.$videourl.'" type="video/mp4"/>';
            $html .= '<p class="vjs-no-js">';
              $html .= 'To view this video please enable JavaScript, and consider upgrading to a web browser that <a href="http://videojs.com html5-video-support/" target="_blank">supports HTML5 video</a>';
              $html .= '</p>';
          $html .= '</video>';
        }
        
        $videoarray = array();
        $videoarray = array(__( "panoid" )=>$panoid,__( "panoviddata" )=>$html,__( "vidid" )=>$vidid,__( "vidurl" )=>$videourl,__( "vidautoplay" )=>$vidautoplay,__( "vidcontrol" )=>$vidcontrol,__( "vidtype" )=>$vidtype); 
        update_post_meta( $postid, 'panodata', $videoarray );
        die();      
      }


      $control = sanitize_text_field($_POST['control']);
      if ($control == 'on') {
        $control = true;
      }
      else {
        $control = false;
      }

      $autoload = sanitize_text_field($_POST['autoload']);
      if ($autoload == 'on') {
        $autoload = true;
      }
      else {
        $autoload = false;
      }

      $default_scene = '';

      $preview = '';
      $preview = esc_url($_POST['preview']);

      $autorotation = '';
      $autorotation = sanitize_text_field($_POST['autorotation']);
      $autorotationinactivedelay = '';
      $autorotationinactivedelay = sanitize_text_field($_POST['autorotationinactivedelay']);
      $autorotationstopdelay = '';
      $autorotationstopdelay = sanitize_text_field($_POST['autorotationstopdelay']);

      $scene_fade_duration = '';
      $scene_fade_duration = $_POST['scenefadeduration'];

      $panodata = $_POST['panodata'];

      //===Error Control and Validation===//

      if ($panodata["scene-list"] != "") {
        foreach ($panodata["scene-list"] as $scenes_val) {
          $scene_id_validate = $scenes_val["scene-id"];
          if (!empty($scene_id_validate)) {
            $scene_id_validated = preg_replace('/[^0-9a-zA-Z_]/',"",$scene_id_validate);
            if ($scene_id_validated != $scene_id_validate) {
              wp_send_json_error('<p><span>Warning:</span> The scene id can only contain letters and numbers.</p>');
              die();
            }

            if (empty($scenes_val["scene-attachment-url"])) {
              wp_send_json_error('<p><span>Warning:</span> A scene image is required for every scene.</p>');
              die();
            }

            if ($scenes_val["hotspot-list"] != "") {
              foreach ($scenes_val["hotspot-list"] as $hotspot_val) {
                $hotspot_title_validate = $hotspot_val["hotspot-title"];
                // if (empty($hotspot_title_validate)) {
                //   wp_send_json_error('<p><span>Warning:</span> Hotspot title is required for every hotspot.</p>');
                //   die();
                // }

                if (!empty($hotspot_title_validate)) {
                  $hotspot_title_validated = preg_replace('/[^0-9a-zA-Z_]/',"",$hotspot_title_validate);
                  if ($hotspot_title_validated != $hotspot_title_validate) {
                    wp_send_json_error('<p><span>Warning:</span> Hotspot title can only contain letters and numbers.</p>');
                    die();
                  }
                  $hotspot_pitch_validate = $hotspot_val["hotspot-pitch"];
                  if (empty($hotspot_pitch_validate)) {
                    wp_send_json_error('<p><span>Warning:</span> Hotspot pitch is required for every hotspot.</p>');
                    die();
                  }
                  if (!empty($hotspot_pitch_validate)) {
                    $hotspot_pitch_validated = preg_replace('/[^0-9.-]/','',$hotspot_pitch_validate);
                    if ($hotspot_pitch_validated != $hotspot_pitch_validate) {
                      wp_send_json_error('<p><span>Warning:</span> Hotspot pitch can only contain float numbers.</p>');
                      die();
                    }
                  }

                  $hotspot_yaw_validate = $hotspot_val["hotspot-yaw"];
                  if (empty($hotspot_yaw_validate)) {
                      wp_send_json_error('<p><span>Warning:</span> Hotspot yaw is required for every hotspot.</p>');
                      die();
                  }
                  if (!empty($hotspot_yaw_validate)) {
                    $hotspot_yaw_validated = preg_replace('/[^0-9.-]/','',$hotspot_yaw_validate);
                    if ($hotspot_yaw_validated != $hotspot_yaw_validate) {
                      wp_send_json_error('<p><span>Warning:</span> Hotspot yaw can only contain float numbers.</p>');
                      die();
                    }
                  }
                  $hotspot_type_validate = $hotspot_val["hotspot-type"];
                  $hotspot_url_validate = $hotspot_val["hotspot-url"];
                  if (!empty($hotspot_url_validate)) {
                    $hotspot_url_validated = esc_url($hotspot_url_validate);
                    if ($hotspot_url_validated != $hotspot_url_validate) {
                      wp_send_json_error('<p><span>Warning:</span> Hotspot Url is invalid.</p>');
                      die();
                    }
                  }
                  $hotspot_content_validate = $hotspot_val["hotspot-content"];

                  $hotspot_scene_validate = $hotspot_val["hotspot-scene"];

                  if ($hotspot_type_validate == "info") {
                    if (!empty($hotspot_scene_validate)) {
                      wp_send_json_error('<p><span>Warning:</span> Don\'t add Target Scene ID on info type hotspot.</p>');
                      die();
                    }
                    if (!empty($hotspot_url_validate) && !empty($hotspot_content_validate)) {
                      wp_send_json_error('<p><span>Warning:</span> Don\'t add Url and On click content both on same hotspot.</p>');
                      die();
                    }
                  }

                  if ($hotspot_type_validate == "scene") {
                    if (empty($hotspot_scene_validate)) {
                      wp_send_json_error('<p><span>Warning:</span> Target scene id is required for scene type hotspot.</p>');
                      die();
                    }
                    if (!empty($hotspot_url_validate) || !empty($hotspot_content_validate)) {
                      wp_send_json_error('<p><span>Warning:</span> Don\'t add Url or On click content on scene type hotspot.</p>');
                      die();
                    }
                  }
                }
              }
            }
          }
        }
      }
      //===Error Control and Validation===//
      foreach ($panodata["scene-list"] as $panoscenes) {
        if ($panoscenes['dscene'] == 'on') {
          $default_scene = $panoscenes['scene-id'];
        }
      }
      if (empty($default_scene)) {
        wp_send_json_error('<p><span>Warning:</span> Default scene is required. Set a scene as deafualt to load it by deafult.</p>');
        die();
      }

      $panolength = count($panodata["scene-list"]);
      for ($i=0; $i < $panolength; $i++) { 
        if (empty($panodata["scene-list"][$i]['scene-id'])) {
          unset($panodata["scene-list"][$i]);
        }
        else {
          $panohotspotlength = count($panodata["scene-list"][$i]['hotspot-list']);
          for ($j=0; $j < $panohotspotlength; $j++) { 
            if (empty($panodata["scene-list"][$i]['hotspot-list'][$j]['hotspot-title'])) {
              unset($panodata["scene-list"][$i]['hotspot-list'][$j]);
            } 
          }
        }
      }
      // echo "<pre>";
      // var_dump($panodata);
      // die();
      $pano_array = array();
      $pano_array = array(__( "panoid" )=>$panoid,__( "autoLoad" )=>$autoload,__( "showControls" )=>$control,__( "autoRotate" )=>$autorotation,__( "autoRotateInactivityDelay" )=>$autorotationinactivedelay,__( "autoRotateStopDelay" )=>$autorotationstopdelay,__( "preview" )=>$preview,__( "defaultscene" )=>$default_scene,__( "scenefadeduration" )=>$scene_fade_duration,__( "panodata" )=>$panodata);


      if (empty($autorotation)) {
          unset($pano_array['autoRotate']);
          unset($pano_array['autoRotateInactivityDelay']);
          unset($pano_array['autoRotateStopDelay']);
      }
      if (empty($autorotationinactivedelay)) {
          unset($pano_array['autoRotateInactivityDelay']);
      }
      if (empty($autorotationstopdelay)) {
          unset($pano_array['autoRotateStopDelay']);
      }
      
      update_post_meta( $postid, 'panodata', $pano_array );
      die();
  }
}
