<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              http://rextheme.com/
 * @since             1.0.0
 * @package           Wpvr
 *
 * @wordpress-plugin
 * Plugin Name:       WP VR
 * Plugin URI:        https://rextheme.com/wp-vr-360-panorama-and-virtual-tour-creator-for-wordpress/
 * Description:       WP VR - 360 Panorama and virtual tour creator for WordPress is a customized panaroma & virtual builder tool for WordPress Website.
 * Version:           2.1.0
 * Author:            Rextheme
 * Author URI:        http://rextheme.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       wpvr
 * Domain Path:       /languages
 */
// If this file is called directly, abort.
if ( !defined( 'WPINC' ) ) {
    die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'WPVR', '1.0.0' );
define( "WPVR_PLUGIN_DIR_URL", plugin_dir_url( __FILE__ ) );
/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-wpvr-activator.php
 */
function activate_wpvr()
{
    require_once plugin_dir_path( __FILE__ ) . 'includes/class-wpvr-activator.php';
    Wpvr_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-wpvr-deactivator.php
 */
function deactivate_wpvr()
{
    require_once plugin_dir_path( __FILE__ ) . 'includes/class-wpvr-deactivator.php';
    Wpvr_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_wpvr' );
register_deactivation_hook( __FILE__, 'deactivate_wpvr' );
/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */

require plugin_dir_path( __FILE__ ) . 'includes/class-wpvr.php';
/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_wpvr()
{
    $plugin = new Wpvr();
    $plugin->run();
}

run_wpvr();
/**
 * array information checker
 */
function wpvr_in_array_r( $needle, $haystack, $strict = false )
{
    foreach ( $haystack as $item ) {
        if ( (( $strict ? $item === $needle : $item == $needle )) || is_array( $item ) && wpvr_in_array_r( $needle, $item, $strict ) ) {
            return true;
        }
    }
    return false;
}

function wpvr_activation_redirect( $plugin )
{

    if ( $plugin == plugin_basename( __FILE__ ) ) {
        exit( wp_redirect( admin_url( 'admin.php?page=wpvr' ) ) );
    }
}

add_action( 'activated_plugin', 'wpvr_activation_redirect' );

register_activation_hook( __FILE__, 'fx_admin_notice_example_activation_hook' );

function fx_admin_notice_example_activation_hook() {
    set_transient( 'wpvr-admin-notice-example', true, 5 );
}
set_transient( 'wpvr-admin-notice-example', true, 5 );
add_action( 'admin_notices', 'wpvr_admin_notice_example_notice' );
function wpvr_admin_notice_example_notice(){

    if( get_transient( 'wpvr-admin-notice-example' ) ){
        $screen = get_current_screen();
        if ($screen->id=="toplevel_page_wpvr") {
           ?>
        <div class="notice notice-warning ">
            <p>Celebrating 1k active installations of WP Vr. Use coupon code wpvr1k to get 20% off from the Pro version until March 7th.</p>
        </div>
        <?php  
        }
       
        delete_transient( 'wpvr-admin-notice-example' );
    }
}

/**
 * Initialize the plugin tracker
 *
 * @return void
 */
function appsero_init_tracker_wpvr() {
 
    if ( ! class_exists( 'AppSero\Insights' ) ) {
        require_once __DIR__ . '/insights.php';
    }
    $insights = new AppSero\Insights( 'cab9761e-b067-4824-9c71-042df5d58598', 'WP VR', __FILE__);
    $insights->optin();
    $insights->init_plugin();
    
}
 
add_action( 'init', 'appsero_init_tracker_wpvr' );

function wpvr_block() {
    wp_register_script(
        'wpvr-block',
        plugins_url( 'build/index.build.js', __FILE__ ),
        array( 'wp-blocks', 'wp-element', 'wp-components', 'wp-editor' )
    );
    wp_enqueue_style(
		'gutyblocks/guty-block',
        plugins_url( 'src/view.css', __FILE__ ),
        array( 'wp-edit-blocks' )
	);

    register_block_type( 'wpvr/wpvr-block', array(
         'attributes'      => array(
            'id' => array(
                'type' => 'string',
            ),
            'width' => array(
                'type' => 'string',
            ),
            'height' => array(
                'type' => 'string',
            ),
            'content' => array(
                'type' => 'string',
                'source'=> 'html',
                'default'=> '<script>          </script>'
            ),
        ),
        'editor_script' => 'wpvr-block',
        'render_callback' => 'wpvr_block_render',
    ) );
}
add_action( 'init', 'wpvr_block' );

function wpvr_block_render( $attributes ) {

    $id = $attributes['id'];
    if (isset($attributes['width'])) {
        $width = $attributes['width'];
    }
    if (isset($attributes['height'])) {
        $height = $attributes['height'];
    }
    

    $postdata = get_post_meta( $id, 'panodata', true );
    $panoid = 'pano'.$id;

    if (isset($postdata['vidid'])) {
        if (empty($width)) {
            $width = '600';
        }
        if (empty($height)) {
            $height = '400';
        }
        $videourl = $postdata['vidurl'];

        if (strpos($videourl, 'youtube') > 0) {
          $explodeid = '';
          $explodeid = explode("=",$videourl);
          $foundid = '';
          $foundid = $explodeid[1];
          $html = '';
          $html .= '<iframe width="'.$width.'" height="'.$height.'" src="https://www.youtube.com/embed/'.$foundid.'" frameborder="0" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>';
          
        } elseif (strpos($videourl, 'vimeo') > 0) {

          $explodeid = '';
          $explodeid = explode("/",$videourl);
          $foundid = '';
          $foundid = $explodeid[3];
          $html = '';
          $html .= '<iframe src="https://player.vimeo.com/video/'.$foundid.'" width="'.$width.'" height="'.$height.'" frameborder="0" webkitallowfullscreen mozallowfullscreen allowfullscreen></iframe>';
          
        } else {
            $html = '';
            $html .= '<div id="pano'.$id.'" class="pano-wrap" style="text-align: center; max-width: '.$width.'px; height: '.$height.'px; margin: 0 auto;">';
                $html .= '<div style="width:100%; height:100%; ">'.$postdata['panoviddata'].'</div>';
                $html .= '<script>';
                    $html .= 'videojs('.$postdata['vidid'].', {';
                        $html .= 'plugins: {';
                            $html .= 'pannellum: {}';
                        $html .= '}';
                    $html .= '});';
                $html .= '</script>';
            $html .= '</div>';
        }
        return $html;
    } 

    $control = false;
    if (isset($postdata['showControls'])) {
        $control = $postdata['showControls'];
    }
    
    $autoload = false;

    if (isset($postdata['autoLoad'])) {
        $autoload = $postdata['autoLoad'];
    }
    
    $default_scene = '';
    if (isset($postdata['defaultscene'])) {
        $default_scene = $postdata['defaultscene'];
    }

    $preview = '';
    if (isset($postdata['preview'])) {
      $preview = $postdata['preview'];
    }

    $autorotation = '';
    if (isset($postdata["autoRotate"])) {
      $autorotation = $postdata["autoRotate"];
    }
    $autorotationinactivedelay = '';
    if (isset($postdata["autoRotateInactivityDelay"])) {
      $autorotationinactivedelay = $postdata["autoRotateInactivityDelay"];
    }
    $autorotationstopdelay = '';
    if (isset($postdata["autoRotateStopDelay"])) {
      $autorotationstopdelay = $postdata["autoRotateStopDelay"];
    }
    
    $scene_fade_duration = '';
    if (isset($postdata['scenefadeduration'])) {
        $scene_fade_duration = $postdata['scenefadeduration'];
    }
    
    $panodata = '';
    if (isset($postdata['panodata'])) {
        $panodata = $postdata['panodata'];
    }
    

      $default_data = array();
      $default_data = array(__( 'firstScene' )=>$default_scene,__( 'sceneFadeDuration' )=>$scene_fade_duration);
      $scene_data = array();

      if (!empty($panodata['scene-list'])) {
            foreach ($panodata['scene-list'] as $panoscenes) {
            $hotspot_datas = array();
            if (isset($panoscenes['hotspot-list'])) {
                $hotspot_datas = $panoscenes['hotspot-list'];
            }
            
            $hotspots = array();
            foreach ($hotspot_datas as $hotspot_data) {

              $hotspot_info = array(
                __( 'text' )=>$hotspot_data['hotspot-title'],
                __( 'pitch' )=>$hotspot_data['hotspot-pitch'],
                __( 'yaw' )=>$hotspot_data['hotspot-yaw'],
                __( 'type' )=>$hotspot_data['hotspot-type'],
                __( 'cssClass' )=>$hotspot_data['hotspot-customclass'],
                __( 'URL' )=>$hotspot_data['hotspot-url'],
                __( 'clickHandlerArgs' )=>$hotspot_data['hotspot-content'],
                __( 'createTooltipArgs' )=>$hotspot_data['hotspot-hover'],
                __( 'sceneId' )=>$hotspot_data['hotspot-scene']);
              array_push($hotspots, $hotspot_info);
            }

            $scene_info = array();
            $scene_info = array(__( 'type' )=>$panoscenes['scene-type'],__( 'panorama' )=>$panoscenes['scene-attachment-url'],__( 'hotSpots' )=>$hotspots);
            $scene_array = array();
            $scene_array = array(
              __($panoscenes['scene-id'])=>$scene_info
            );
            $scene_data[$panoscenes['scene-id']] = $scene_info;
        }   
      }

      $pano_id_array = array();
      $pano_id_array = array(__( 'panoid' )=>$panoid);
      $pano_response = array();
      $pano_response = array(__( 'autoLoad' )=>$autoload,__( 'showControls' )=>$control,__( "preview" )=>$preview,__( "autoRotate" )=>$autorotation,__( "autoRotateInactivityDelay" )=>$autorotationinactivedelay,__( "autoRotateStopDelay" )=>$autorotationstopdelay,__( 'default' )=>$default_data,__( 'scenes' )=>$scene_data);
      if (empty($autorotation)) {
          unset($pano_response['autoRotate']);
          unset($pano_response['autoRotateInactivityDelay']);
          unset($pano_response['autoRotateStopDelay']);
      }
      if (empty($autorotationinactivedelay)) {
          unset($pano_response['autoRotateInactivityDelay']);
      }
      if (empty($autorotationstopdelay)) {
          unset($pano_response['autoRotateStopDelay']);
      }
      
      $response = array();
      $response = array($pano_id_array,$pano_response);
      if (!empty($response)) {
        $response = json_encode($response);
    }
    if (empty($width)) {
        $width = '600';
    }
    if (empty($height)) {
        $height = '400';
    }
    $class = 'myclass';
    $html = 'test';
    $html = '';

    $html .= '<div id="pano'.$id.'" class="pano-wrap" style="text-align: center; max-width: '.$width.'px; height: '.$height.'px; margin: 0 auto;">';
        $html .= '<i class="fa fa-times" id="cross"></i>';
        $html .= '<div id="custom-ifram" style="display: none;">';
        $html .= '</div>';
    $html .= '</div>';
    //script started
    $html .= '<script>';
        $html .= 'var response = '.$response.';';
        $html .= 'var scenes = response[1];';
        $html .= 'if(scenes) {';
            $html .= 'var scenedata = scenes.scenes;';
            $html .= 'for(var i in scenedata) {';
                $html .= 'var scenehotspot = scenedata[i].hotSpots;';
                $html .= 'for(var i = 0; i < scenehotspot.length; i++) {';
                    $html .= 'if(scenehotspot[i]["clickHandlerArgs"] != "") {';
                        $html .= 'scenehotspot[i]["clickHandlerFunc"] = wpvrhotspot;';
                    $html .= '}'; 
                    $html .= 'if(scenehotspot[i]["createTooltipArgs"] != "") {';
                        $html .= 'scenehotspot[i]["createTooltipFunc"] = wpvrtooltip;';
                    $html .= '}';   
                $html .= '}';    
            $html .= '}';
        $html .= '}';    
        $html .= 'pannellum.viewer(response[0]["panoid"], scenes);';
    $html .= '</script>';
    //script end
    return $html;
}

  /**
  * Add REST API support to an already registered post type.
  */
  add_action( 'init', 'my_custom_post_type_rest_support', 25 );
  function my_custom_post_type_rest_support() {
  	global $wp_post_types;
  
  	//be sure to set this to the name of your post type!
  	$post_type_name = 'wpvr_item';
  	if( isset( $wp_post_types[ $post_type_name ] ) ) {
  		$wp_post_types[$post_type_name]->show_in_rest = true;
  		$wp_post_types[$post_type_name]->rest_base = $post_type_name;
  		$wp_post_types[$post_type_name]->rest_controller_class = 'WP_REST_Posts_Controller';
  	}
  
  }

add_action('rest_api_init', 'wpvr_rest_data_route');
function wpvr_rest_data_route() {
    register_rest_route( 'wpvr/v1', '/panodata/(?P<id>\d+)', array(
        'methods' => 'GET',
        'callback' => 'wpvr_rest_data_set',
      ) );
}
function wpvr_rest_data_set($data) {
    $id = $data['id']; 
    $postdata = get_post_meta( $id, 'panodata', true );
    $panoid = 'pano'.$id;
    $control = false;
    if (isset($postdata['showControls'])) {
        $control = $postdata['showControls'];
    }
    
    $autoload = false;

    if (isset($postdata['autoLoad'])) {
        $autoload = $postdata['autoLoad'];
    }
    
    $default_scene = '';
    if (isset($postdata['defaultscene'])) {
        $default_scene = $postdata['defaultscene'];
    }
    
    $scene_fade_duration = '';
    if (isset($postdata['scenefadeduration'])) {
        $scene_fade_duration = $postdata['scenefadeduration'];
    }
    
    $panodata = '';
    if (isset($postdata['panodata'])) {
        $panodata = $postdata['panodata'];
    }
    

        $default_data = array();
        $default_data = array(__( "firstScene" )=>$default_scene,__( "sceneFadeDuration" )=>$scene_fade_duration);
        $scene_data = array();

        if (!empty($panodata["scene-list"])) {
            foreach ($panodata["scene-list"] as $panoscenes) {

            $hotspot_datas = $panoscenes["hotspot-list"];
            $hotspots = array();
            foreach ($hotspot_datas as $hotspot_data) {

                $hotspot_info = array(
                __( "text" )=>$hotspot_data["hotspot-title"],
                __( "pitch" )=>$hotspot_data["hotspot-pitch"],
                __( "yaw" )=>$hotspot_data["hotspot-yaw"],
                __( "type" )=>$hotspot_data["hotspot-type"],
                __( "cssClass" )=>$hotspot_data["hotspot-customclass"],
                __( "URL" )=>$hotspot_data["hotspot-url"],
                __( "clickHandlerArgs" )=>$hotspot_data["hotspot-content"],
                __( "createTooltipArgs" )=>$hotspot_data["hotspot-hover"],
                __( "sceneId" )=>$hotspot_data["hotspot-scene"]);
                array_push($hotspots, $hotspot_info);
            }

            $scene_info = array();
            $scene_info = array(__( "type" )=>$panoscenes["scene-type"],__( "panorama" )=>$panoscenes["scene-attachment-url"],__( "hotSpots" )=>$hotspots);
            $scene_array = array();
            $scene_array = array(
                __($panoscenes["scene-id"])=>$scene_info
            );
            $scene_data[$panoscenes["scene-id"]] = $scene_info;
        }	
        }

        $pano_id_array = array();
        $pano_id_array = array(__( "panoid" )=>$panoid);
        $pano_response = array();
        $pano_response = array(__( "autoLoad" )=>$autoload,__( "showControls" )=>$control,__( "default" )=>$default_data,__( "scenes" )=>$scene_data);
        $response = array();
        $response = array($pano_id_array,$pano_response);
        if (!empty($response)) {
        $response = json_encode($response);
    }
    return $response;
}

function wpvr_upgrade_to_pro_link( $links ) {
    $links = array_merge( array(
        '<a href="' . esc_url( 'https://rextheme.com/wpvr/' ) . '">' . __( 'Upgrade to pro', 'wpvr' ) . '</a>'
    ), $links );
    return $links;
}
add_action( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'wpvr_upgrade_to_pro_link' );
